@@ -1,6 +1,6 @@
 import logging
 from sqlalchemy import and_
-from sqlalchemy.exc import IntegrityError
+from sqlalchemy.exc import IntegrityError, InvalidRequestError
 from sqlalchemy.orm.exc import ObjectDeletedError
 
 from vwsfriend.model.climatization import Climatization
@@ -13,7 +13,7 @@ LOG = logging.getLogger("VWsFriend")
 class ClimatizationAgent():
     def __init__(self, session, vehicle):
         self.session = session
-        self.vehicle = vehicle
+        self.vehicle = session.merge(vehicle)
         self.climate = session.query(Climatization).filter(and_(Climatization.vehicle == vehicle,
                                                                 Climatization.carCapturedTimestamp.isnot(None))) \
                                                    .order_by(Climatization.carCapturedTimestamp.desc()).first()
@@ -26,9 +26,9 @@ class ClimatizationAgent():
                     self.__onCarCapturedTimestampChange,
                     AddressableLeaf.ObserverEvent.VALUE_CHANGED,
                     onUpdateComplete=True)
-                self.__onCarCapturedTimestampChange(None, None)
+                self.__onCarCapturedTimestampChange(self.vehicle.weConnectVehicle.domains['climatisation']['climatisationStatus'].carCapturedTimestamp, None)
 
-    def __onCarCapturedTimestampChange(self, element, flags):
+    def __onCarCapturedTimestampChange(self, element, flags):  # noqa: C901
         if element is not None and element.value is not None:
             climateStatus = self.vehicle.weConnectVehicle.domains['climatisation']['climatisationStatus']
             current_remainingClimatisationTime_min = None
@@ -46,6 +46,11 @@ class ClimatizationAgent():
                     self.climate = self.session.query(Climatization).filter(and_(Climatization.vehicle == self.vehicle,
                                                                                  Climatization.carCapturedTimestamp.isnot(None))) \
                         .order_by(Climatization.carCapturedTimestamp.desc()).first()
+                except InvalidRequestError:
+                    LOG.warning('Last climatisation entry was not persisted')
+                    self.climate = self.session.query(Climatization).filter(and_(Climatization.vehicle == self.vehicle,
+                                                                                 Climatization.carCapturedTimestamp.isnot(None))) \
+                        .order_by(Climatization.carCapturedTimestamp.desc()).first()
 
             if self.climate is None or (self.climate.carCapturedTimestamp != climateStatus.carCapturedTimestamp.value and (
                     self.climate.remainingClimatisationTime_min != current_remainingClimatisationTime_min
@@ -53,12 +58,12 @@ class ClimatizationAgent():
 
                 self.climate = Climatization(self.vehicle, climateStatus.carCapturedTimestamp.value, current_remainingClimatisationTime_min,
                                              current_climatisationState)
-                try:
-                    with self.session.begin_nested():
+                with self.session.begin_nested():
+                    try:
                         self.session.add(self.climate)
-                    self.session.commit()
-                except IntegrityError as err:
-                    LOG.warning('Could not add climatization entry to the database, this is usually due to an error in the WeConnect API (%s)', err)
+                    except IntegrityError as err:
+                        LOG.warning('Could not add climatization entry to the database, this is usually due to an error in the WeConnect API (%s)', err)
+                self.session.commit()
 
     def commit(self):
-        pass
+        self.session.commit()
