@@ -1,10 +1,16 @@
-from sqlalchemy import Column, Integer, String, ForeignKey, UniqueConstraint
-from sqlalchemy.orm import relationship
+from sqlalchemy import Column, Integer, String, ForeignKey, Table, UniqueConstraint
+from sqlalchemy.orm import relationship, backref
 
 from vwsfriend.model.base import Base
 from vwsfriend.model.datetime_decorator import DatetimeDecorator
 
 
+journey_tag_association_table = Table('journey_tag', Base.metadata,
+                                      Column('journey_id', ForeignKey('journey.id')),
+                                      Column('tag_name', ForeignKey('tag.name'))
+                                      )
+
+
 class Journey(Base):
     __tablename__ = 'journey'
     __table_args__ = (
@@ -17,6 +23,7 @@ class Journey(Base):
     vehicle = relationship("Vehicle")
     title = Column(String)
     description = Column(String)
+    tags = relationship("Tag", secondary=journey_tag_association_table, backref=backref("journey"))
 
     def __init__(self, vehicle, start, end, title):
         self.vehicle = vehicle
